import React from 'react';
import Pagination from '@material-ui/lab/Pagination';
import SearchIcon from '@material-ui/icons/Search';
import {
  InputBase,
  Typography,
  Table,
  TableBody,
  TableCell,
  TableHead,
  TableRow,
  Grid,
  Button,
  Paper,
  IconButton,
} from '@material-ui/core';

class Table_ extends React.Component {

  renderAddButton = () => {
    if ( this.props.addHref ) {
      return (
        <Button
            variant="contained"
            component="a"
            href={this.props.addHref}
            color="primary"
            className="TableAddButton"
            style={{ float: 'right', height: '48px' }} >
          Add +
        </Button>
      );
    }
  }

  renderTableTitle = () => {
    if ( this.props.title ) {
      return (
        <Typography
            component="h2"
            variant="h6"
            color="primary"
            style={{ float: 'left' }}
            gutterBottom >
          {this.props.title}
        </Typography>
      );
    }
  }

  renderPagination = () => {
    if ( this.props.pagination ) {
      return (
        <Pagination
            style={{ float: 'right' }}
            count={this.props.pagination}
            onChange={this.props.onChangePage} />
      );
    }
  }

  renderSearch = () => {
    if ( this.props.search ) {
      return (
        <div style={{ float: 'left', paddingRight: '10px' }}>
          <Paper
              component='form'
               >
            <InputBase 
                placeholder="Search"
                inputProps={{ 'aria-label': 'search' }}
                style={{ paddingLeft: '5px' }}
                onChange={(event) => this.handleSearchText(event.target.value)}
                onKeyPress={(event) => this.handleKeyPress(event)} />
            <IconButton
                onClick={() => this.handleSearchClick()}>
              <SearchIcon  />
            </IconButton>
          </Paper>
        </div>
      );
    }
  }

  handleSearchText = (value) => {
    this.props.handleSearchText(value);
  }

  handleSearchClick = () => {
    this.props.onSearchClick();
  }

  handleKeyPress = (event) => {
    if ( event.key === 'Enter' ) {
      this.props.onSearchClick();
      event.preventDefault();
    }
  }

  render () {
    return (
      <React.Fragment>
        <Grid container spacing={3}>
          <Grid item xs={12}>
            {this.renderTableTitle()}
            <div style={{ float: 'right' }}>
              {this.renderSearch()}
              {this.renderAddButton()}
            </div>
          </Grid>
        </Grid>
        <Table size="small">
          <TableHead>
            <TableRow>
              {this.props.columns.map(column => (
                <TableCell key={column.name}>{column.name}</TableCell>
              ))}
            </TableRow>
          </TableHead>
          <TableBody>
            {this.props.data.map((row, idx) => (
              <TableRow key={idx}>
                {this.props.columns.map((column, idx) => {
                  if ( column.type === 'link' ) {
                    return (
                      <TableCell key={idx}>
                        <a href={row.href}>
                          {row[column.key]}
                        </a>
                      </TableCell>
                    );
                  } else if ( column.type === 'image' ) {
                    if ( row[column.key] !== '' ) {
                      return (
                        <TableCell key={idx}>
                          <img src={`${column.imagePath}${row[column.key]}`} />
                        </TableCell>
                      );
                    } else {
                      return (
                        <TableCell key={idx}>
                          <img src={column.imageOnError} style={{ ...column.imageOnErrorStyle }} />
                        </TableCell>
                      );
                    }
                  } else {
                    return (
                      <TableCell key={idx}>
                        {row[column.key]}
                      </TableCell>
                    );
                  }
                })}
              </TableRow>
            ))}
          </TableBody>
        </Table>
        <Grid container spacing={3}>
          <Grid item xs={12}>
            {this.renderPagination()}
          </Grid>
        </Grid>
      </React.Fragment>
    );

  }

}

export default Table_;